var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import createComponent from '../../utils/createComponent';
import buttonColors from '../../utils/buttonColors';
import sizes from '../../utils/sizes';

var Button = forwardRef(function (_ref, ref) {
  var tag = _ref.tag,
      type = _ref.type,
      active = _ref.active,
      outline = _ref.outline,
      color = _ref.color,
      size = _ref.size,
      props = _objectWithoutProperties(_ref, ['tag', 'type', 'active', 'outline', 'color', 'size']);

  var Tag = props.href && tag === 'button' ? 'a' : tag;

  var className = cn('btn', 'btn-' + size, 'btn' + (outline ? '-outline' : '') + '-' + color, { active: active, disabled: props.disabled }, props.className);

  return React.createElement(Tag, _extends({ ref: ref }, props, Tag === 'button' ? { type: type } : {}, { className: className }));
});

Button.displayName = 'Button';

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  active: PropTypes.bool,
  className: PropTypes.string,
  color: PropTypes.oneOf(buttonColors),
  disabled: PropTypes.bool,
  href: PropTypes.string,
  outline: PropTypes.bool,
  size: PropTypes.oneOf(sizes),
  tag: PropTypes.oneOfType([PropTypes.elementType, PropTypes.func, PropTypes.string]),
  type: PropTypes.string
} : {};

Button.defaultProps = {
  active: false,
  className: undefined,
  color: 'primary',
  disabled: false,
  href: undefined,
  outline: false,
  size: 'md',
  tag: 'button',
  type: 'button'
};

Button.Group = createComponent('Button.Group', 'btn-group');

Button.Toolbar = createComponent('Button.Toolbar', 'btn-toolbar');

export default Button;